@@ -3,28 +3,25 @@
 
 #ifndef __WNCK_ENUM_TYPES_H__
 #define __WNCK_ENUM_TYPES_H__
-
 /* enumerations from "pager.h" */
-
 GType wnck_pager_display_mode_get_type (void);
 #define WNCK_TYPE_PAGER_DISPLAY_MODE (wnck_pager_display_mode_get_type())
-
+/* enumerations from "screen.h" */
+GType wnck_motion_direction_get_type (void);
+#define WNCK_TYPE_MOTION_DIRECTION (wnck_motion_direction_get_type())
 /* enumerations from "tasklist.h" */
-
 GType wnck_tasklist_grouping_type_get_type (void);
 #define WNCK_TYPE_TASKLIST_GROUPING_TYPE (wnck_tasklist_grouping_type_get_type())
-
+/* enumerations from "util.h" */
+GType wnck_client_type_get_type (void);
+#define WNCK_TYPE_CLIENT_TYPE (wnck_client_type_get_type())
 /* enumerations from "window.h" */
-
 GType wnck_window_state_get_type (void);
 #define WNCK_TYPE_WINDOW_STATE (wnck_window_state_get_type())
-
 GType wnck_window_actions_get_type (void);
 #define WNCK_TYPE_WINDOW_ACTIONS (wnck_window_actions_get_type())
-
 GType wnck_window_type_get_type (void);
 #define WNCK_TYPE_WINDOW_TYPE (wnck_window_type_get_type())
-
 #endif /* __WNCK_ENUM_TYPES_H__ */
 
 /* Generated data ends here */
